@@ -2,8 +2,8 @@
 pub const TYPE_ACCOUNT_PORTFOLIO_ACCOUNT:u8=0;
 pub const TYPE_ACCOUNT_USER_PORTFOLIO_ACCOUNT:u8=1;
 pub const TYPE_ACCOUNT_NFT_ACCOUNT:u8=2;
-pub const TYPE_ACCOUNT_TURING_ACCOUNT:u8=3;
+pub const TYPE_ACCOUNT_TURING_MASHINE_ACCOUNT:u8=3;
 pub const TYPE_ACCOUNT_ADMIN_ACCOUNT:u8=4;
-pub const TYPE_ACCOUNT_TURING_TRIGGUER_ACCOUNT:u8=5;
+pub const TYPE_ACCOUNT_TRIGGUER_TURING_MASHINE_ACCOUNT:u8=5;
 pub const TYPE_ACCOUNT_AIRDROP_ACCOUNT:u8=8;
 
