@@ -34,12 +34,12 @@ pub const INSTRUCTION_TRANSFER_WITH_CROSS:u8=31;
 pub const INSTRUCTION_UPDATE_SPLU_TURING_MASHINE:u8=32;
 pub const INSTRUCTION_UPDATE_STATE_PPU:u8=33;
 pub const INSTRUCTION_RESET_SPLU_TERTIARY_PPU:u8=34;
-pub const INSTRUCTION_CLAIM_REWARDS:u8=35;
+pub const INSTRUCTION_UPDATE_SPLU_TERTIARY_PPU:u8=35;
 pub const INSTRUCTION_TRANSFER_REWARDS:u8=36;
-pub const INSTRUCTION_INVEST_MORE:u8=37;
 pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
 pub const INSTRUCTION_CLOSE_TURING_MASHINE:u8=39;
 pub const INSTRUCTION_CLOSE_PPM:u8=40;
+pub const INSTRUCTION_MINT_TO_CROSS:u8=41;
 pub const EXTERNAL_INSTRUCTION_WITHDRAW_SABER: u8 = 3;
 pub const WITHDRAW_INSTRUCTION_SABER: u8 = 3;
 pub const EXTERNAL_INSTRUCTION_APPROVE_SPL: u8 = 4;
